
References
~~~~~~~~~~~

If there is anything important or relevant or latest missing in the list below, let me know and I will update it. Thanks.

This list will be updated regularly. Stay tuned!

- Age Correction in Dementia – Matching to a Healthy Brain. (n.d.). https://doi.org/10.1371/journal.pone.0022193
- Brown, M. R. G., Sidhu, G. S., Greiner, R., Asgarian, N., Bastani, M., Silverstone, P. H., Greenshaw, A. J., & Dursun, S. M. (2012). ADHD-200 Global Competition: Diagnosing ADHD using personal characteristic data can outperform resting state fMRI measurements. Frontiers in Systems Neuroscience, 6. https://doi.org/10.3389/fnsys.2012.00069
- Dorie, V., Hill, J., Shalit, U., Scott, M., & Cervone, D. (2019). Automated versus Do-It-Yourself Methods for Causal Inference: Lessons Learned from a Data Analysis Competition. Statistical Science, 34(1), 43–68. https://doi.org/10.1214/18-STS667
- Ferrari, E., Bosco, P., Calderoni, S., Oliva, P., Palumbo, L., Spera, G., Fantacci, M. E., & Retico, A. (2020). Dealing with confounders and outliers in classification medical studies: The Autism Spectrum Disorders case study. Artificial Intelligence in Medicine, 101926. https://doi.org/10.1016/j.artmed.2020.101926
- Gagnon-Bartsch, J. A., & Speed, T. P. (2012). Using control genes to correct for unwanted variation in microarray data. Biostatistics, 13(3), 539–552. https://doi.org/10.1093/biostatistics/kxr034
- Garcia-Dias, R., Scarpazza, C., Baecker, L., Vieira, S., Pinaya, W. H. L., Corvin, A., Redolfi, A., Nelson, B., Crespo-Facorro, B., McDonald, C., Tordesillas-Gutiérrez, D., Cannon, D., Mothersill, D., Hernaus, D., Morris, D., Setien-Suero, E., Donohoe, G., Frisoni, G., Tronchin, G., … Mechelli, A. (2020). Neuroharmony: A new tool for harmonizing volumetric MRI data from unseen scanners. NeuroImage, 117127. https://doi.org/10.1016/j.neuroimage.2020.117127
- Goh, W. W. B., Wang, W., & Wong, L. (2017). Why Batch Effects Matter in Omics Data, and How to Avoid Them. Trends in Biotechnology, 35(6), 498–507. https://doi.org/10.1016/j.tibtech.2017.02.012
- Görgen, K., Hebart, M. N., Allefeld, C., & Haynes, J.-D. (2018). The same analysis approach: Practical protection against the pitfalls of novel neuroimaging analysis methods. NeuroImage, 180, 19–30. https://doi.org/10.1016/j.neuroimage.2017.12.083
- Greenland, S., & Morgenstern, H. (2001). Confounding in Health Research. Annual Review of Public Health, 22(1), 189–212. https://doi.org/10.1146/annurev.publhealth.22.1.189
- Harrell, F. (n.d.). Biostatistics for Biomedical Research.
- Hyatt, C. S., Owens, M. M., Crowe, M. L., Carter, N. T., Lynam, D. R., & Miller, J. D. (2019). The quandary of covarying: A brief review and empirical examination of covariate use in structural neuroimaging studies on psychological variables. NeuroImage, 116225. https://doi.org/10.1016/j.neuroimage.2019.116225
- Kaltenpoth, D., & Vreeken, J. (2019). We Are Not Your Real Parents: Telling Causal from Confounded using MDL. In Proceedings of the 2019 SIAM International Conference on Data Mining (Vol. 1–0, pp. 199–207). Society for Industrial and Applied Mathematics. https://doi.org/10.1137/1.9781611975673.23
- Kia, S. M., Huijsdens, H., Dinga, R., Wolfers, T., Mennes, M., Andreassen, O. A., Westlye, L. T., Beckmann, C. F., & Marquand, A. F. (2020). Hierarchical Bayesian Regression for Multi-Site Normative Modeling of Neuroimaging Data. ArXiv:2005.12055 [Cs, Stat]. http://arxiv.org/abs/2005.12055
- Kostro, D., Abdulkadir, A., Durr, A., Roos, R., Leavitt, B. R., Johnson, H., Cash, D., Tabrizi, S. J., Scahill, R. I., Ronneberger, O., & Klöppel, S. (2014). Correction of inter-scanner and within-subject variance in structural MRI based automated diagnosing. NeuroImage, 98, 405–415. https://doi.org/10.1016/j.neuroimage.2014.04.057
- Linn, K. A., Gaonkar, B., Doshi, J., Davatzikos, C., & Shinohara, R. T. (2015). Addressing Confounding in Predictive Models with an Application to Neuroimaging. The International Journal of Biostatistics, 12(1), 31–44. https://doi.org/10.1515/ijb-2015-0030
- Little, M. A., Varoquaux, G., Saeb, S., Lonini, L., Jayaraman, A., Mohr, D. C., & Kording, K. P. (2017). Using and understanding cross-validation strategies. Perspectives on Saeb et al. GigaScience, 6(5). https://doi.org/10.1093/gigascience/gix020
- Lu, Z., & Ku, Y. (2020). NeuroRA: A Python Toolbox of Representational Analysis from Multi-modal Neural Data [Preprint]. Neuroscience. https://doi.org/10.1101/2020.03.25.008086
- Marquand, A. F., Wolfers, T., & Dinga, R. (2019). Phenomapping: Methods and Measures for Deconstructing Diagnosis in Psychiatry. In I. C. Passos, B. Mwangi, & F. Kapczinski (Eds.), Personalized Psychiatry: Big Data Analytics in Mental Health (pp. 119–134). Springer International Publishing. https://doi.org/10.1007/978-3-030-03553-2_7
- McNamee, R. (2005). Regression modelling and other methods to control confounding. Occupational and Environmental Medicine, 62(7), 500–506. https://doi.org/10.1136/oem.2002.001115
- Mielke, M., Vemuri, P., & Rocca, W. (2014). Clinical epidemiology of Alzheimer&rsquo;s disease: Assessing sex and gender differences. Clinical Epidemiology, 37. https://doi.org/10.2147/CLEP.S37929
- Neto, E. C. (2020). Causality-aware counterfactual confounding adjustment for feature representations learned by deep models. ArXiv:2004.09466 [Cs, Stat]. http://arxiv.org/abs/2004.09466
- Neto, E. C., Pratap, A., Perumal, T. M., Tummalacherla, M., Bot, B. M., Mangravite, L., & Omberg, L. (2018). Using permutations to assess confounding in machine learning applications for digital health. ArXiv:1811.11920 [Stat]. http://arxiv.org/abs/1811.11920
- Neto, E. C., Pratap, A., Perumal, T. M., Tummalacherla, M., Bot, B. M., Trister, A. D., Friend, S. H., Mangravite, L., & Omberg, L. (2017). Learning Disease vs Participant Signatures: A permutation test approach to detect identity confounding in machine learning diagnostic applications. ArXiv:1712.03120 [Stat]. http://arxiv.org/abs/1712.03120
- Nguyen, H., Morris, R. W., Harris, A. W., Korgoankar, M. S., & Ramos, F. (2018). Correcting differences in multi-site neuroimaging data using Generative Adversarial Networks. ArXiv:1803.09375 [Cs]. http://arxiv.org/abs/1803.09375
- Parmigiani, G. (2003). The analysis of gene expression data: Methods and software. Springer. http://public.eblib.com/choice/publicfullrecord.aspx?p=231804
- Parr, T., & Wilson, J. D. (2019). A Stratification Approach to Partial Dependence for Codependent Variables. ArXiv:1907.06698 [Cs, Stat]. http://arxiv.org/abs/1907.06698
- Pervaiz, U., Vidaurre, D., Woolrich, M. W., & Smith, S. M. (2020). Optimising network modelling methods for fMRI. NeuroImage, 211, 116604. https://doi.org/10.1016/j.neuroimage.2020.116604
- Pomponio, R., Erus, G., Habes, M., Doshi, J., Srinivasan, D., Mamourian, E., Bashyam, V., Nasrallah, I. M., Satterthwaite, T. D., Fan, Y., Launer, L. J., Masters, C. L., Maruff, P., Zhuo, C., Völzke, H., Johnson, S. C., Fripp, J., Koutsouleris, N., Wolf, D. H., … Davatzikos, C. (2020). Harmonization of large MRI datasets for the analysis of brain imaging patterns throughout the lifespan. NeuroImage, 208, 116450. https://doi.org/10.1016/j.neuroimage.2019.116450
- Rao, A., Monteiro, J. M., Mourão-Miranda, J., & Alzheimer’s Disease Initiative. (2017). Predictive Modelling using Neuroimaging Data in the Presence of Confounds. NeuroImage. https://doi.org/10.1016/j.neuroimage.2017.01.066
- Saeb, S., Lonini, L., Jayaraman, A., Mohr, D. C., & Kording, K. P. (2017). The need to approximate the use-case in clinical machine learning. GigaScience, 6(5). https://doi.org/10.1093/gigascience/gix019
- Snoek, L., Miletić, S., & Scholte, H. S. (2019). How to control for confounds in decoding analyses of neuroimaging data. NeuroImage, 184, 741–760. https://doi.org/10.1016/j.neuroimage.2018.09.074
- Touvron, H., Faisan, S., Tilquin, F., & Noblet, V. (2019). Pitfalls Related To Computer-Aided Diagnosis System Learned From Multiple Databases. 2019 IEEE 16th International Symposium on Biomedical Imaging (ISBI 2019), 806–809. https://doi.org/10.1109/ISBI.2019.8759550
- VanderWeele, T. J. (2019). Principles of confounder selection. European Journal of Epidemiology, 34(3), 211–219. https://doi.org/10.1007/s10654-019-00494-6
- VanderWeele, T. J., & Shpitser, I. (2013). On the definition of a confounder. The Annals of Statistics, 41(1). https://doi.org/10.1214/12-AOS1058
- Wachinger, C., Becker, B. G., Rieckmann, A., & Pölsterl, S. (2019). Quantifying Confounding Bias in Neuroimaging Datasets with Causal Inference. ArXiv:1907.04102 [Cs, Eess, Stat]. http://arxiv.org/abs/1907.04102
- Wachinger, C., & Reuter, M. (2016). Domain adaptation for Alzheimer’s disease diagnostics. NeuroImage, 139, 470–479. https://doi.org/10.1016/j.neuroimage.2016.05.053
- Wang, Y., & Blei, D. M. (2019). The Blessings of Multiple Causes. ArXiv:1805.06826 [Cs, Stat]. http://arxiv.org/abs/1805.06826
- Yamashita, A., Yahata, N., Itahashi, T., Lisi, G., Yamada, T., Ichikawa, N., Takamura, M., Yoshihara, Y., Kunimatsu, A., Okada, N., Yamagata, H., Matsuo, K., Hashimoto, R., Okada, G., Sakai, Y., Morimoto, J., Narumoto, J., Shimada, Y., Kasai, K., … Imamizu, H. (2019). Harmonization of resting-state functional MRI data across multiple imaging sites via the separation of site differences into sampling bias and measurement bias. PLOS Biology, 17(4), e3000042. https://doi.org/10.1371/journal.pbio.3000042



